==> zio-aws-cognitoidentityprovider_2.12-5.17.146.1-sources.jar: zio/aws/cognitoidentityprovider/model/StringAttributeConstraintsType.scala <==
package zio.aws.cognitoidentityprovider.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cognitoidentityprovider.model.primitives.StringType
import scala.jdk.CollectionConverters._
final case class StringAttributeConstraintsType(
    minLength: Option[StringType] = None,
    maxLength: Option[StringType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentityprovider.model.StringAttributeConstraintsType = {
    import StringAttributeConstraintsType.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentityprovider.model.StringAttributeConstraintsType
      .builder()
      .optionallyWith(minLength.map(value => value: java.lang.String))(
        _.minLength
      )
      .optionallyWith(maxLength.map(value => value: java.lang.String))(
        _.maxLength
      )
      .build()
  }
  def asReadOnly
      : zio.aws.cognitoidentityprovider.model.StringAttributeConstraintsType.ReadOnly =
    zio.aws.cognitoidentityprovider.model.StringAttributeConstraintsType
      .wrap(buildAwsValue())
}
object StringAttributeConstraintsType {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentityprovider.model.StringAttributeConstraintsType
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cognitoidentityprovider.model.StringAttributeConstraintsType =
      zio.aws.cognitoidentityprovider.model.StringAttributeConstraintsType(
        minLength.map(value => value),
        maxLength.map(value => value)
      )
    def minLength: Option[StringType]
    def maxLength: Option[StringType]
    def getMinLength: ZIO[Any, AwsError, StringType] =
      AwsError.unwrapOptionField("minLength", minLength)
    def getMaxLength: ZIO[Any, AwsError, StringType] =
      AwsError.unwrapOptionField("maxLength", maxLength)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.StringAttributeConstraintsType
  ) extends zio.aws.cognitoidentityprovider.model.StringAttributeConstraintsType.ReadOnly {
    override val minLength: Option[StringType] =
      scala.Option(impl.minLength()).map(value => value: StringType)
    override val maxLength: Option[StringType] =
      scala.Option(impl.maxLength()).map(value => value: StringType)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.StringAttributeConstraintsType
  ): zio.aws.cognitoidentityprovider.model.StringAttributeConstraintsType.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-cognitoidentityprovider_2.13-5.17.112.1-sources.jar: zio/aws/cognitoidentityprovider/model/StringAttributeConstraintsType.scala <==
package zio.aws.cognitoidentityprovider.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cognitoidentityprovider.model.primitives.StringType
import scala.jdk.CollectionConverters._
final case class StringAttributeConstraintsType(
    minLength: Option[StringType] = None,
    maxLength: Option[StringType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentityprovider.model.StringAttributeConstraintsType = {
    import StringAttributeConstraintsType.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentityprovider.model.StringAttributeConstraintsType
      .builder()
      .optionallyWith(
        minLength.map(value => StringType.unwrap(value): java.lang.String)
      )(_.minLength)
      .optionallyWith(
        maxLength.map(value => StringType.unwrap(value): java.lang.String)
      )(_.maxLength)
      .build()
  }
  def asReadOnly
      : zio.aws.cognitoidentityprovider.model.StringAttributeConstraintsType.ReadOnly =
    zio.aws.cognitoidentityprovider.model.StringAttributeConstraintsType
      .wrap(buildAwsValue())
}
object StringAttributeConstraintsType {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentityprovider.model.StringAttributeConstraintsType
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cognitoidentityprovider.model.StringAttributeConstraintsType =
      zio.aws.cognitoidentityprovider.model.StringAttributeConstraintsType(
        minLength.map(value => value),
        maxLength.map(value => value)
      )
    def minLength: Option[StringType]
    def maxLength: Option[StringType]
    def getMinLength: ZIO[Any, AwsError, StringType] =
      AwsError.unwrapOptionField("minLength", minLength)
    def getMaxLength: ZIO[Any, AwsError, StringType] =
      AwsError.unwrapOptionField("maxLength", maxLength)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.StringAttributeConstraintsType
  ) extends zio.aws.cognitoidentityprovider.model.StringAttributeConstraintsType.ReadOnly {
    override val minLength: Option[StringType] = scala
      .Option(impl.minLength())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.primitives.StringType(value)
      )
    override val maxLength: Option[StringType] = scala
      .Option(impl.maxLength())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.primitives.StringType(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.StringAttributeConstraintsType
  ): zio.aws.cognitoidentityprovider.model.StringAttributeConstraintsType.ReadOnly =
    new Wrapper(impl)
}
